sqlobject.tests.test_asdict module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_asdict module

class `sqlobject.tests.test_asdict.` `SOTestAsDict`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_as_dict
  property `name`
  property `name2`
  `q` = so_test_as_dict
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_asdict.SOTestAsDict`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_as_dict'

`sqlobject.tests.test_asdict.` `test_asDict`()